import React, { useState } from 'react';

const NPCForm = () => {
  const [formData, setFormData] = useState({
    gender: '',
    race: '',
    height: '',
    eyeColor: '',
    hairColor: '',
  });

  const [npc, setNpc] = useState(null);
  const [error, setError] = useState(null);

  const handleChange = (e) => {
    setFormData({
      ...formData,
      [e.target.name]: e.target.value,
    });
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    setError(null);
    try {
      const response = await fetch('/api/generate-npc', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify(formData),
      });
      if (!response.ok) {
        throw new Error('Failed to generate NPC');
      }
      const npcData = await response.json();
      setNpc(npcData);
    } catch (error) {
      setError(error.message);
    }
  };

  return (
    <div>
      <form onSubmit={handleSubmit}>
        <label>
          Gender:
          <input type="text" name="gender" value={formData.gender} onChange={handleChange} required />
        </label>
        <label>
          Race:
          <input type="text" name="race" value={formData.race} onChange={handleChange} required />
        </label>
        <label>
          Height:
          <input type="text" name="height" value={formData.height} onChange={handleChange} required />
        </label>
        <label>
          Eye Color:
          <input type="text" name="eyeColor" value={formData.eyeColor} onChange={handleChange} required />
        </label>
        <label>
          Hair Color:
          <input type="text" name="hairColor" value={formData.hairColor} onChange={handleChange} required />
        </label>
        <button type="submit">Generate NPC</button>
      </form>

      {error && <p style={{ color: 'red' }}>{error}</p>}

      {npc && (
        <div>
          <h2>Generated NPC</h2>
          <p>Gender: {npc.gender}</p>
          <p>Race: {npc.race}</p>
          <p>Height: {npc.height}</p>
          <p>Eye Color: {npc.eyeColor}</p>
          <p>Hair Color: {npc.hairColor}</p>
          <img src={npc.image} alt="Generated NPC" />
        </div>
      )}
    </div>
  );
};

export default NPCForm;
