<?php

function runCommand($command) {
    $output = [];
    $return_var = 0;
    exec($command, $output, $return_var);
    foreach ($output as $line) {
        echo $line . "<br>";
    }
    return $return_var;
}

function extractZip($zipFile, $extractTo) {
    $zip = new ZipArchive;
    if ($zip->open($zipFile) === TRUE) {
        $zip->extractTo($extractTo);
        $zip->close();
        return true;
    } else {
        return false;
    }
}

function createEnvFile($path, $content) {
    $file = fopen($path, "w");
    fwrite($file, $content);
    fclose($file);
}

// Check if the zip file exists
$zipFile = 'MonosDMTools.zip';
if (!file_exists($zipFile)) {
    die('Zip file not found. Please upload MonosDMTools.zip to the same directory as this script.');
}

$rootDir = __DIR__;
$backendDir = $rootDir . '/backend';
$frontendDir = $rootDir . '/frontend';

// Extract the zip file
echo "Extracting files...<br>";
if (!extractZip($zipFile, $rootDir)) {
    die('Failed to extract zip file.');
}

// Install frontend dependencies
echo "Installing frontend dependencies...<br>";
if (runCommand("cd $frontendDir && npm install") !== 0) {
    die('Failed to install frontend dependencies.');
}

// Install backend dependencies
echo "Installing backend dependencies...<br>";
if (runCommand("cd $backendDir && npm install") !== 0) {
    die('Failed to install backend dependencies.');
}

// Create .env file
echo "Creating .env file...<br>";
createEnvFile("$backendDir/.env", "OPENAI_API_KEY=your_openai_api_key_here");

// Build frontend
echo "Building frontend...<br>";
if (runCommand("cd $frontendDir && npm run build") !== 0) {
    die('Failed to build frontend.');
}

// Move build files to backend
echo "Moving build files to backend...<br>";
runCommand("rm -rf $backendDir/public");
if (runCommand("mv $frontendDir/build $backendDir/public") !== 0) {
    die('Failed to move build files to backend.');
}

echo "Setup complete! You can now run 'npm start' in the backend directory to start the application.";
?>
